#[repr(C)]pub enum OpTypes {
ProfilerInactive = 0,
ProfilerCollectingSample = 1,
ProfilerUnwinding = 2,
ProfilerSerializing = 3,
SIZE = 4,
}Expand description
This enum represents operations a the tracked library might be engaged in. Currently only implemented for profiling. The idea is that if a crash consistently occurs while a particular operation is ongoing, its likely related.
In the future, we might also track wall-clock time of operations (or some statistical sampling thereof) using the same enum.
NOTE: This enum is known to be non-exhaustive. Feel free to add new types as needed.
Variants
ProfilerInactive = 0
ProfilerCollectingSample = 1
ProfilerUnwinding = 2
ProfilerSerializing = 3
SIZE = 4
Dummy value to allow easier iteration
Implementations