#[repr(C)]pub enum StacktraceCollection {
Disabled = 0,
WithoutSymbols = 1,
EnabledWithInprocessSymbols = 2,
EnabledWithSymbolsInReceiver = 3,
}Expand description
Stacktrace collection occurs in the context of a crashing process. If the stack is sufficiently corruputed, it is possible (but unlikely), for stack trace collection itself to crash. We recommend fully enabling stacktrace collection, but having an environment variable to allow downgrading the collector.
Variants
Disabled = 0
WithoutSymbols = 1
EnabledWithInprocessSymbols = 2
This option uses backtrace::resolve_frame_unsynchronized() to gather symbol information
and also unwind inlined functions. Enabling this feature will not only provide symbolic
details, but may also yield additional or less stack frames compared to other
configurations.
EnabledWithSymbolsInReceiver = 3