pub fn disable()Expand description
Disables the crashtracker. Note that this does not restore the old signal handlers, but rather turns crash-tracking into a no-op, and then chains the old handlers. This means that handlers registered after the crashtracker will continue to work as expected.
Preconditions
None
Safety
None
Atomicity
This function is atomic and idempotent. Calling it multiple times is allowed.