reset_counters

Function reset_counters 

pub fn reset_counters() -> Result<(), CounterError>
Resets all counters to 0. Expected to be used after a fork, to reset the counters on the child ATOMICITY: The reset of each individual counter is atomic, but the entire reset is NOT. Should only be used when no conflicting updates can occur, e.g. after a fork but before ops start on the child.