update_metadata

Function update_metadata 

pub fn update_metadata(metadata: Metadata) -> Result<()>
Updates the crashtracker metadata for this process Metadata is stored in a global variable and sent to the crashtracking receiver when a crash occurs.

PRECONDITIONS: None SAFETY: Crash-tracking functions are not guaranteed to be reentrant. No other crash-handler functions should be called concurrently. ATOMICITY: This function uses a swap on an atomic pointer.