pub struct CrashPingBuilder { /* private fields */ }Implementations
Sourceimpl CrashPingBuilder
impl CrashPingBuilder
Sourcepub fn new(crash_uuid: Uuid) -> Self
pub fn new(crash_uuid: Uuid) -> Self
Crash pings should only be initalized and built by the CrashInfoBuilder We require the crash uuid to be passed in because a CrashPing is always associated with a specific crash.
pub fn with_sig_info(self, sig_info: SigInfo) -> Self
pub fn with_custom_message(self, message: String) -> Self
pub fn with_kind(self, kind: ErrorKind) -> Self
pub fn with_metadata(self, metadata: Metadata) -> Self
pub fn build(self) -> Result<CrashPing>