pub struct SigInfo {
pub si_addr: Option<String>,
pub si_code: c_int,
pub si_code_human_readable: SiCodes,
pub si_signo: c_int,
pub si_signo_human_readable: SignalNames,
}Fields
si_addr: Option<String>si_code: c_intsi_code_human_readable: SiCodessi_signo: c_intsi_signo_human_readable: SignalNamesTrait Implementations
Sourceimpl<'de> Deserialize<'de> for SigInfo
impl<'de> Deserialize<'de> for SigInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SigInfo
impl JsonSchema for SigInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for SigInfo