pub struct ThreadData {
pub crashed: bool,
pub name: String,
pub stack: StackTrace,
pub state: Option<String>,
}Fields
crashed: boolname: Stringstack: StackTracestate: Option<String>Trait Implementations
Sourceimpl Clone for ThreadData
impl Clone for ThreadData
Sourcefn clone(&self) -> ThreadData
fn clone(&self) -> ThreadData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadData
impl Debug for ThreadData
Sourceimpl<'de> Deserialize<'de> for ThreadData
impl<'de> Deserialize<'de> for ThreadData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ThreadData
impl JsonSchema for ThreadData
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ThreadData
impl PartialEq for ThreadData
Sourceimpl Serialize for ThreadData
impl Serialize for ThreadData
impl StructuralPartialEq for ThreadData