pub struct CrashPing { /* private fields */ }Implementations
Sourceimpl CrashPing
impl CrashPing
pub fn crash_uuid(&self) -> &str
pub fn message(&self) -> &str
pub fn metadata(&self) -> &Metadata
pub fn siginfo(&self) -> Option<&SigInfo>
pub fn kind(&self) -> ErrorKind
pub fn upload_to_endpoint(&self, endpoint: &Option<Endpoint>) -> Result<()>
Sourcepub async fn upload_to_endpoint_async(
&self,
endpoint: &Option<Endpoint>,
) -> Result<()>
pub async fn upload_to_endpoint_async( &self, endpoint: &Option<Endpoint>, ) -> Result<()>
Sends this crash ping telemetry event to indicate that crash processing has started. We no-op on file endpoints because unlike production environments, we know if a crash report failed to send when file debugging.