pub struct TelemetryCrashUploader { /* private fields */ }Implementations
Sourceimpl TelemetryCrashUploader
impl TelemetryCrashUploader
pub fn new( crashtracker_metadata: &Metadata, endpoint: &Option<Endpoint>, ) -> Result<Self>
Sourcepub async fn upload_general_log(
&self,
message: String,
tags: String,
level: LogLevel,
) -> Result<()>
pub async fn upload_general_log( &self, message: String, tags: String, level: LogLevel, ) -> Result<()>
Send a general (non crash report, non crash ping) log message to the telemetry log intake.
Sourcepub async fn upload_crash_ping(&self, crash_ping: &CrashPing) -> Result<()>
pub async fn upload_crash_ping(&self, crash_ping: &CrashPing) -> Result<()>
Send a crash ping telemetry log to indicate that crash processing has started
Sourcepub async fn upload_crash_info(&self, crash_info: &CrashInfo) -> Result<()>
pub async fn upload_crash_info(&self, crash_info: &CrashInfo) -> Result<()>
Send a crash info telemetry log to indicate that crash processing has completed